@@ -6,6 +6,8 @@ from .test_node import TestNode
 from .test_association import TestAssociation
 from .test_attachment import TestAttachment
 from .test_file_folder import TestFileFolder
+from .test_project import TestProject
+from .test_release import TestRelease
 
 def create_suite():
     suite = unittest.TestSuite()
@@ -16,6 +18,8 @@ def create_suite():
     suite.addTest(TestAssociation)
     suite.addTest(TestAttachment)
     suite.addTest(TestFileFolder)
+    suite.addTest(TestProject)
+    suite.addTest(TestRelease)
 
     return suite
 
